]> granicus.if.org Git - neomutt/commitdiff
fix odd case of Charset_is_utf8
authorRichard Russon <rich@flatcap.org>
Tue, 6 Mar 2018 16:49:30 +0000 (16:49 +0000)
committerRichard Russon <rich@flatcap.org>
Tue, 13 Mar 2018 17:05:00 +0000 (17:05 +0000)
hcache/hcache.c
menu.c
mutt/charset.c
mutt/charset.h
mutt/mbyte.c
pager.c

index 1d289332ea9f1569a9a1a55ffbd3ff9d4eef0fac..4b0a4696005bd4724005a46e452eeb6b391c9653 100644 (file)
@@ -627,7 +627,7 @@ static void *hcache_dump(header_cache_t *h, struct Header *header, int *off,
 {
   unsigned char *d = NULL;
   struct Header nh;
-  bool convert = !Charset_is_utf8;
+  bool convert = !CharsetIsUtf8;
 
   *off = 0;
   d = lazy_malloc(sizeof(union Validate));
@@ -685,7 +685,7 @@ struct Header *mutt_hcache_restore(const unsigned char *d)
 {
   int off = 0;
   struct Header *h = mutt_new_header();
-  bool convert = !Charset_is_utf8;
+  bool convert = !CharsetIsUtf8;
 
   /* skip validate */
   off += sizeof(union Validate);
diff --git a/pager.c b/pager.c
index 335cf33ddf450044fec6307dbf92e1aef22c5d52..56375c43c256918ba29d70bc2dcd325d01a0aa83 100644 (file)
--- a/pager.c
+++ b/pager.c
@@ -1255,7 +1255,7 @@ static int format_line(struct Line **line_info, int n, unsigned char *buf, int f
     if (k == 0)
       k = 1;
 
-    if (Charset_is_utf8)
+    if (CharsetIsUtf8)
     {
       /* zero width space, zero width no-break space */
       if (wc == 0x200B || wc == 0xFEFF)
@@ -1314,14 +1314,14 @@ static int format_line(struct Line **line_info, int n, unsigned char *buf, int f
     }
 
     /* no-break space, narrow no-break space */
-    if (IsWPrint(wc) || (Charset_is_utf8 && (wc == 0x00A0 || wc == 0x202F)))
+    if (IsWPrint(wc) || (CharsetIsUtf8 && (wc == 0x00A0 || wc == 0x202F)))
     {
       if (wc == ' ')
       {
         space = ch;
       }
       /* no-break space, narrow no-break space */
-      else if (Charset_is_utf8 && (wc == 0x00A0 || wc == 0x202F))
+      else if (CharsetIsUtf8 && (wc == 0x00A0 || wc == 0x202F))
       {
         /* Convert non-breaking space to normal space. The local variable
          * `space' is not set here so that the caller of this function won't
diff --git a/menu.c b/menu.c
index e55ad7af41e5029cbee454720734376cb22e4491..05d77f135bb70816a21b390525c551e70194a811 100644 (file)
--- a/menu.c
+++ b/menu.c
@@ -132,7 +132,7 @@ static void print_enriched_string(int index, int attr, unsigned char *s, int do_
             else
               add_wch(WACS_LLCORNER);
 #else
-            else if (Charset_is_utf8)
+            else if (CharsetIsUtf8)
               addstr("\342\224\224"); /* WACS_LLCORNER */
             else
               addch(ACS_LLCORNER);
@@ -145,7 +145,7 @@ static void print_enriched_string(int index, int attr, unsigned char *s, int do_
             else
               add_wch(WACS_ULCORNER);
 #else
-            else if (Charset_is_utf8)
+            else if (CharsetIsUtf8)
               addstr("\342\224\214"); /* WACS_ULCORNER */
             else
               addch(ACS_ULCORNER);
@@ -158,7 +158,7 @@ static void print_enriched_string(int index, int attr, unsigned char *s, int do_
             else
               add_wch(WACS_LTEE);
 #else
-            else if (Charset_is_utf8)
+            else if (CharsetIsUtf8)
               addstr("\342\224\234"); /* WACS_LTEE */
             else
               addch(ACS_LTEE);
@@ -171,7 +171,7 @@ static void print_enriched_string(int index, int attr, unsigned char *s, int do_
             else
               add_wch(WACS_HLINE);
 #else
-            else if (Charset_is_utf8)
+            else if (CharsetIsUtf8)
               addstr("\342\224\200"); /* WACS_HLINE */
             else
               addch(ACS_HLINE);
@@ -184,7 +184,7 @@ static void print_enriched_string(int index, int attr, unsigned char *s, int do_
             else
               add_wch(WACS_VLINE);
 #else
-            else if (Charset_is_utf8)
+            else if (CharsetIsUtf8)
               addstr("\342\224\202"); /* WACS_VLINE */
             else
               addch(ACS_VLINE);
@@ -197,7 +197,7 @@ static void print_enriched_string(int index, int attr, unsigned char *s, int do_
             else
               add_wch(WACS_TTEE);
 #else
-            else if (Charset_is_utf8)
+            else if (CharsetIsUtf8)
               addstr("\342\224\254"); /* WACS_TTEE */
             else
               addch(ACS_TTEE);
@@ -210,7 +210,7 @@ static void print_enriched_string(int index, int attr, unsigned char *s, int do_
             else
               add_wch(WACS_BTEE);
 #else
-            else if (Charset_is_utf8)
+            else if (CharsetIsUtf8)
               addstr("\342\224\264"); /* WACS_BTEE */
             else
               addch(ACS_BTEE);
index a448e37b32c55c4a5573ba55df89032348c3e460..730834e217a86be977f0833aa4644a13de27e057 100644 (file)
@@ -57,9 +57,9 @@ char *Charset;        /**< Config: User's choice of character set */
 wchar_t ReplacementChar = '?';
 
 /**
* Charset_is_utf8 - Is the user's current character set utf-8?
  */
-bool Charset_is_utf8 = false;
+bool CharsetIsUtf8 = false;
 
 /**
  * struct Lookup - Regex to String lookup table
@@ -906,12 +906,12 @@ void mutt_ch_set_charset(char *charset)
 
   if (mutt_ch_is_utf8(buffer))
   {
-    Charset_is_utf8 = true;
+    CharsetIsUtf8 = true;
     ReplacementChar = 0xfffd; /* replacement character */
   }
   else
   {
-    Charset_is_utf8 = false;
+    CharsetIsUtf8 = false;
     ReplacementChar = '?';
   }
 
index 3447e6d5c2ab044a51e77aaae831bb136416a0c7..13c44a8c66fb52826558c876b4acd93ed6cdb5c7 100644 (file)
@@ -32,7 +32,7 @@ struct Buffer;
 
 extern char *AssumedCharset;
 extern char *Charset;
-extern bool Charset_is_utf8;
+extern bool CharsetIsUtf8;
 extern wchar_t ReplacementChar;
 
 /**
index 1806dbe10852c8983096a24de655240553259012..a9cc43021ca2223e94d059941ab45cbf8393b92e 100644 (file)
@@ -432,7 +432,7 @@ int mutt_mb_filter_unprintable(char **s)
     }
     if (!IsWPrint(wc))
       wc = '?';
-    else if (Charset_is_utf8 && mutt_mb_is_display_corrupting_utf8(wc))
+    else if (CharsetIsUtf8 && mutt_mb_is_display_corrupting_utf8(wc))
       continue;
     k2 = wcrtomb(scratch, wc, &mbstate2);
     scratch[k2] = '\0';
@@ -57,9 +57,9 @@ char *Charset;        /**< Config: User's choice of character set */
 
 /**
- * Charset_is_utf8 - Is the user's current character set utf-8?
+ * CharsetIsUtf8 - Is the user's current character set utf-8?
  */